==> cxf-services-xkms-common-2.7.15-sources.jar: org/apache/cxf/xkms/model/xkms/ReasonEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ReasonEnum.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ReasonEnum">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI">
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#IssuerTrust"/>
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#RevocationStatus"/>
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#ValidityInterval"/>
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Signature"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "ReasonEnum")
@XmlEnum
public enum ReasonEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#IssuerTrust")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_ISSUER_TRUST("http://www.w3.org/2002/03/xkms#IssuerTrust"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#RevocationStatus")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REVOCATION_STATUS("http://www.w3.org/2002/03/xkms#RevocationStatus"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#ValidityInterval")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_VALIDITY_INTERVAL("http://www.w3.org/2002/03/xkms#ValidityInterval"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Signature")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_SIGNATURE("http://www.w3.org/2002/03/xkms#Signature");
    private final String value;

    ReasonEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static ReasonEnum fromValue(String v) {
        for (ReasonEnum c: ReasonEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> cxf-services-xkms-common-3.0.11-sources.jar: org/apache/cxf/xkms/model/xkms/ReasonEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ReasonEnum.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ReasonEnum"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI"&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#IssuerTrust"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#RevocationStatus"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#ValidityInterval"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Signature"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "ReasonEnum")
@XmlEnum
public enum ReasonEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#IssuerTrust")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_ISSUER_TRUST("http://www.w3.org/2002/03/xkms#IssuerTrust"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#RevocationStatus")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REVOCATION_STATUS("http://www.w3.org/2002/03/xkms#RevocationStatus"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#ValidityInterval")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_VALIDITY_INTERVAL("http://www.w3.org/2002/03/xkms#ValidityInterval"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Signature")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_SIGNATURE("http://www.w3.org/2002/03/xkms#Signature");
    private final String value;

    ReasonEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static ReasonEnum fromValue(String v) {
        for (ReasonEnum c: ReasonEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
